#ifndef MAPFUNCARG_H
#define MAPFUNCARG_H

#include <map>
#include <string>
#include <functional>

//map function to (minimum input, minimum output)
std::map <std::string,std::pair<int,int>> 
minInOut{
	{"add_gaussian_noise",make_pair(3,0)},
	{"compute_cloud_error",make_pair(4,1)},
	{"compute_crop_to_hull",make_pair(4,0)},
	{"cluster_extraction",make_pair(3,0)},
	{"compute_hausdorff", make_pair(3,1)},
	{"compute_hull", make_pair(3,0)},
	{"concatenate_points_pcd", make_pair(3,0)},
	{"extract_feature",make_pair(3,0)},
	{"fast_bilateral_filter",make_pair(3,0)},
	{"fpfh_estimation",make_pair(3,0)},
	{"generate", make_pair(2,0)},
	{"gp3_surface", make_pair(3,0)},
	{"grid_min", make_pair(3,0)},
	{"marching_cubes_reconstruction", make_pair(3,0)},
	{"mesh_sampling",make_pair(3,0)},
	{"normal_estimation", make_pair(3,0)},
	{"obj2pcd", make_pair(3,0)},
	{"obj2ply", make_pair(3,0)},
	{"outlier_removal",make_pair(3,0)},
	{"passthrough_filter",make_pair(3,0)},
	{"pcd2ply",make_pair(3,0)},
	{"pcd2png", make_pair(3,0)},
	{"pcd2vtk",make_pair(3,0)},
	{"pcd_change_viewpoint", make_pair(3,0)},
	{"pcd_viewer",make_pair(2,0)},
	{"pclzf2pcd",make_pair(3,0)},
	{"plane_projection",make_pair(3,0)},
	{"ply2pcd",make_pair(3,0)},
	{"ply2vtk", make_pair(3,0)},
	{"poisson_reconstruction",make_pair(3,0)},
	{"progressive_morphological_filter",make_pair(3,0)},
	{"radius_filter", make_pair(3,0)},
	{"transform_from_viewpoint",make_pair(3,0)},
	{"transform_point_cloud",make_pair(3,0)},
	{"uniform_sampling",make_pair(3,0)},
	{"vfh_estimation", make_pair(3,0)},
	{"voxel_grid",make_pair(3,0)},
	{"vtk2obj", make_pair(3,0)},
	{"vtk2pcd", make_pair(3,0)},
	{"vtk2ply", make_pair(3,0)},
	{"xyz2pcd",make_pair(3,0)} 
	};

//map function in string to function
std::map <std::string,std::function<void(double* ,int, char**)>> 
mapFunc2{
	{"compute_cloud_error",compute_cloud_error},
	{"compute_hausdorff",compute_hausdorff_distance}
};

std::map <std::string,std::function<void(int, char**)>> 
mapFunc{
	{"add_gaussian_noise",add_gaussian_noise},
	{"compute_crop_to_hull",crop_to_hull},
	{"cluster_extraction",cluster_extraction},
	{"compute_hull", compute_hull},
	{"concatenate_points_pcd", concatenate_points_pcd},
	{"extract_feature",extract_feature},
	{"fast_bilateral_filter",fast_bilateral_filter},
	{"fpfh_estimation",fpfh_estimation},
	{"generate", generate},
	{"gp3_surface", gp3_surface},
	{"grid_min", grid_min},
	{"marching_cubes_reconstruction", marching_cubes_reconstruction},
	{"mesh_sampling",mesh_sampling},
	{"normal_estimation", normal_estimation},
	{"obj2pcd", obj2pcd},
	{"obj2ply",  obj2ply},
	{"outlier_removal",outlierRemoval},
	{"passthrough_filter",passthrough_filter},
	{"pcd2ply",pcd2ply},
	{"pcd2png", pcd2png},
	{"pcd2vtk",pcd2vtk},
	{"pcd_change_viewpoint", pcd_change_viewpoint},
	{"pcd_viewer",pcd_viewer},
	{"pclzf2pcd",pclzf2pcd},
	{"plane_projection",plane_projection},
	{"ply2pcd",ply2pcd},
	{"ply2vtk",ply2vtk},
	{"poisson_reconstruction",poisson_reconstruction},
	{"progressive_morphological_filter",progressive_morphological_filter},
	{"radius_filter", radius_filter},
	{"transform_from_viewpoint",transform_from_viewpoint},
	{"transform_point_cloud",transform_point_cloud},
	{"uniform_sampling",uniform_sampling},
	{"vfh_estimation", vfh_estimation},
	{"voxel_grid",voxel_grid},
	{"vtk2obj",vtk2obj},
	{"vtk2pcd", vtk2pcd},
	{"vtk2ply",vtk2ply},
	{"xyz2pcd",xyz2pcd} 

};
#endif


